@@ -110,7 +110,7 @@ def psychrometric_constant(pressure):
     pressure is used for each location (Equation 7), the psychrometric
     constant is kept constant for each location.
 
-    A table listing the psychometric constant for different altitudes is
+    A table listing the psychrometric constant for different altitudes is
     located here: https://www.fao.org/3/X0490E/x0490e0j.htm
 
     Parameters
@@ -132,28 +132,24 @@ def psychrometric_constant(pressure):
     array([0.0398844, 0.0531792, 0.066474 ])
     """
 
-    x_out = False
-    if isinstance(pressure, xr.DataArray):
-        x_out = True
-        save_dims = pressure.dims
-        save_coords = pressure.coords
-
-    # convert inputs to numpy arrays if necessary
-    if not _is_duck_array(pressure):
-        pressure = np.asarray(pressure)
-
+    # Constant
     con = 0.66474e-3
 
-    psy_const = con * pressure
+    in_type = type(pressure)
 
-    # reformat output for xarray if necessary
-    if x_out:
-        heatindex = xr.DataArray(psy_const, coords=save_coords, dims=save_dims)
-        heatindex.attrs['long_name'] = "psychrometric constant"
-        heatindex.attrs['units'] = "kPa/C"
-        heatindex.attrs[
+    # Psychrometric constant calculation
+    # if input not xarray, make sure in numpy for calculation
+    if in_type is not xr.DataArray:
+        psy_const = con * np.asarray(pressure)
+
+    # else if input is xarray, add relevant metadata for xarray output
+    else:
+        psy_const = con * pressure
+        psy_const.attrs['long_name'] = "psychrometric constant"
+        psy_const.attrs['units'] = "kPa/C"
+        psy_const.attrs[
             'url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
-        heatindex.attrs['info'] = "FAO 56; EQN 8; psychrometric_constant"
+        psy_const.attrs['info'] = "FAO 56; EQN 8; psychrometric_constant"
 
     return psy_const
 
@@ -196,28 +192,29 @@ def saturation_vapor_pressure(temperature, tfill=np.NAN):
     array([1.22796262, 1.76730647, 2.50402976])
     """
 
-    x_out = False
-    if isinstance(temperature, xr.DataArray):
-        x_out = True
-        save_dims = temperature.dims
-        save_coords = temperature.coords
+    in_type = type(temperature)
 
-    # convert inputs to numpy arrays for function call if necessary
-    if not _is_duck_array(temperature):
-        temperature = np.asarray(temperature, dtype='float32')
+    if in_type is xr.DataArray:
 
-    temp_c = (temperature - 32) * 5 / 9
-    svp = np.where(temp_c > 0, 0.6108 * np.exp(
-        (17.27 * temp_c) / (temp_c + 237.3)), tfill)
+        # convert temperature to Celsius
+        temp_c = (temperature - 32) * 5 / 9
 
-    # reformat output for xarray if necessary
-    if x_out:
-        heatindex = xr.DataArray(svp, coords=save_coords, dims=save_dims)
-        heatindex.attrs['long_name'] = "saturation vapor pressure"
-        heatindex.attrs['units'] = "kPa"
-        heatindex.attrs[
-            'url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
-        heatindex.attrs['info'] = "FAO 56; EQN 11; saturation_vapor_pressure"
+        # calculate svp
+        svp = xr.where(temp_c > 0, 0.6108 * np.exp(
+            (17.27 * temp_c) / (temp_c + 237.3)), tfill)
+
+        # add relevant metadata
+        svp.attrs['long_name'] = "saturation vapor pressure"
+        svp.attrs['units'] = "kPa"
+        svp.attrs['url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
+        svp.attrs['info'] = "FAO 56; EQN 11; saturation_vapor_pressure"
+
+    else:
+        temperature = np.asarray(temperature)
+
+        temp_c = (temperature - 32) * 5 / 9
+        svp = np.where(temp_c > 0, 0.6108 * np.exp(
+            (17.27 * temp_c) / (temp_c + 237.3)), tfill)
 
     return svp
 
@@ -258,28 +255,16 @@ def actual_saturation_vapor_pressure(tdew, tfill=np.NAN):
     array([1.22796262, 1.76730647, 2.50402976])
     """
 
-    x_out = False
-    if isinstance(tdew, xr.DataArray):
-        x_out = True
-        save_dims = tdew.dims
-        save_coords = tdew.coords
-
-    # convert inputs to numpy arrays if necessary
-    if not _is_duck_array(tdew):
-        tdew = np.asarray(tdew)
+    in_type = type(tdew)
 
     asvp = saturation_vapor_pressure(tdew, tfill)
 
-    # reformat output for xarray if necessary
-    if x_out:
-        heatindex = xr.DataArray(asvp, coords=save_coords, dims=save_dims)
-        heatindex.attrs[
-            'long_name'] = "actual saturation vapor pressure via Tdew"
-        heatindex.attrs['units'] = "kPa"
-        heatindex.attrs[
-            'url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
-        heatindex.attrs[
-            'info'] = "FAO 56; EQN 14; actual_saturation_vapor_pressure"
+    # reformat metadata for xarray
+    if in_type is xr.DataArray:
+        asvp.attrs['long_name'] = "actual saturation vapor pressure via Tdew"
+        asvp.attrs['units'] = "kPa"
+        asvp.attrs['url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
+        asvp.attrs['info'] = "FAO 56; EQN 14; actual_saturation_vapor_pressure"
 
     return asvp
 
@@ -315,31 +300,37 @@ def saturation_vapor_pressure_slope(temperature, tfill=np.NAN):
     array([0.08224261, 0.11322096, 0.153595  ])
     """
 
-    x_out = False
-    if isinstance(temperature, xr.DataArray):
-        x_out = True
-        save_dims = temperature.dims
-        save_coords = temperature.coords
+    in_type = type(temperature)
 
-    # convert inputs to numpy arrays for function call if necessary
-    if not _is_duck_array(temperature):
-        temperature = np.asarray(temperature, dtype='float32')
+    if in_type is xr.DataArray:
 
-    # convert to Celsius
-    temp_c = (temperature - 32) * 5 / 9
+        # convert to Celsius
+        temp_c = (temperature - 32) * 5 / 9
 
-    svp_slope = np.where(
-        temp_c > 0, 4096 * (0.6108 * np.exp(
-            (17.27 * temp_c) / (temp_c + 237.3)) / (temp_c + 237.3)**2), tfill)
+        # calculate svp_slope
+        svp_slope = xr.where(
+            temp_c > 0, 4096 * (0.6108 * np.exp(
+                (17.27 * temp_c) / (temp_c + 237.3)) / (temp_c + 237.3)**2),
+            tfill)
 
-    # reformat output for xarray if necessary
-    if x_out:
-        heatindex = xr.DataArray(svp_slope, coords=save_coords, dims=save_dims)
-        heatindex.attrs['long_name'] = "slope saturation vapor pressure curve"
-        heatindex.attrs['units'] = "kPa/C"
-        heatindex.attrs[
+        # add relevant metadata
+        svp_slope.attrs['long_name'] = "slope saturation vapor pressure curve"
+        svp_slope.attrs['units'] = "kPa/C"
+        svp_slope.attrs[
             'url'] = "https://www.fao.org/docrep/X0490E/x0490e07.htm"
-        heatindex.attrs[
+        svp_slope.attrs[
             'info'] = "FAO 56; EQN 13; saturation_vapor_pressure_slope"
 
+    else:
+        temperature = np.asarray(temperature)
+
+        # convert to Celsius
+        temp_c = (temperature - 32) * 5 / 9
+
+        # calculate svp_slope
+        svp_slope = np.where(
+            temp_c > 0, 4096 * (0.6108 * np.exp(
+                (17.27 * temp_c) / (temp_c + 237.3)) / (temp_c + 237.3)**2),
+            tfill)
+
     return svp_slope
